# Build Instructions

The build instructions below are divided into two parts, namely pre-assembly and final assembly. In the pre-assembly some of the sub-assmeblies or parts are either prepared or assembled together to ease the final assembly. The number in the (#) paranthesis denotes the quantity of the part required.

## Hardware

| Part | Picture |
| ---- | ---- |
| **Button Head Cap Screw (BHCS)** - These screws have a hex head and require an allen wrench | <img src="pictures/hardware_bhcs.PNG" width="300" />  |
| **Socket Head Cap Screw (SHCS)** - These screws have a hex head that require an allen wrench | <img src="pictures/hardware_shcs.PNG" width="300" /> |
| **DIN 433 M3 Washer** - Thin precise washers that are used as spacers between idler pulleys | <img src="pictures/hardware_washer.png" width="300" /> |
| **Smooth idler pulley** - The smooth side of the backside of a timing belt moves on a smooth idler pulley | <img src="pictures/hardware_smooth_idler.PNG" width="300" /> |
| **Teethed Idler pulley** - The toothed side of a timing belt moves on a teethed idler pulley | <img src="pictures/hardware_teethed_idler.PNG" width="300" /> |
| **Drive pulley** - Sits on a motor shaft and is always teethed. Comes with two set screws that need a ##1.5 allen wrench | <img src="pictures/hardware_drive_pulley.PNG" width="300" /> |
| **Heatset insert** - Brass insert with ridges on the outside and a female thread on the inside. They are pressed into printed parts using a soldering iron | <img src="pictures/" width="300" /> |
| **Set screw** - Headless screws with external threads and a hex key on one side. Found on drive pulleys and in the L brackets to join two aluminium profiles | LINK | 
| **L bracket** - L shaped connector with 2 set screws, used to connect two profiles at a right angle | LINK |
| **3030 angle connector** - Aluminium connectors that connect profiles on the plane. Each angle connector requires 2 SHCSs and 2 hammer nuts | LINK |
| **Allen wrench** - Tool with a hex head to tighten Socket head cap screws SHCS | LINK |
| **Flat head screwdriver** - Tool to tighten flat head screws and found on the controller board and electronic wire terminals | LINK |
| **Cross head screwdriver** - Tool to tighten cross head screws and found on the controller board with electronic wire terminals | LINK |

## Pre-Assembly
---


#### Parts required

1. XY Idler Assembly Left (1)
2. XY Stepper Motor Bracket (1)
   1. Nema 17 Motor (1)
   2. GT2 20T Drive Pulley (1)
   3. M3x8mm SHCS (1)
   4. M3x10mm SHCS (2)
3. 10mm dia 340mm long Smooth Rod (1)
4. LMW10U Bearing (1)

### 1. XY Idler Left

##### Parts required

1. XY Idler Assembly Left (1)
   1. Printed XY Idler - Left (1)
      1. M3 Nut (2)
      2. M3x20mm bolt (1)
         1. M3x30mm bolt (1)
      3. 3mm Bore GT2 Pulleys (2)
      4. M3 shim washer (4)
      5. Tool #2.5 Allen Wrench

##### Before and After Assembly

| Before Assembly | After Assembly |
| ---- | ---- |
| <img src="pictures/yaxis_l_xyidler_c0b.PNG" width="350" /> | <img src="pictures/yaxis_l_xyidler_c0a.PNG" width="350" /> |

##### Exploded view of XY Idler

<img src="pictures/yaxis_l_xyidler_cev.PNG" />

##### Step 0 - Prepare parts required for build

1. Printed XY Idler bracket - Left (1)
2. M3 Nut (2)
3. M3x20mm bolt (1)
4. M3x30mm bolt (1)
5. 3mm bore GT2 Pulley (2)
6. M3 shim washer (4-5)
7. Allen wrench #2.5

<img src="pictures/yaxis_l_xyidler_b001.svg" width="600" /> <br> Figure: Parts requiered to assemble XY Idler assembly (Left)


##### Step 1 - Insert 2x M3 nuts into printed XY Idler bracket

| Step 1 - Insert M3 nuts into slots | Step 1.1 - M3 nuts inserted |
| - | - |
| <img src="pictures/yaxis_l_xyidler_c001.PNG" /> | <img src="pictures/yaxis_l_xyidler_c002.PNG" width="350" /> |

##### Step 2 - Insert 2x M3 bolts into printed XY Idler bracket

- Insert the M3x20mm bolt till the end but do not tighten now. It will be tightened in a later step when the 10mm smooth rod is inserted
- Insert the M3x30mm bolt only halfway through

| Insert M3 bolts | M3 bolts inserted |
| - | - |
| <img src="pictures/yaxis_l_xyidler_c003.PNG" width="350" /> | <img src="pictures/yaxis_l_xyidler_c004.PNG" width="350" /> |

##### Step 3 - Insert first GT2 Pulley
- The GT2 Pulley has a bore diameter of 3mm and width of 6mm

| Insert GT2 Idler pulley | GT2 pulley inserted |
| - | - |
| <img src="pictures/yaxis_l_xyidler_c005.PNG" width="350" /> | <img src="pictures/yaxis_l_xyidler_c006.PNG" width="350" /> |

##### Step 4 - Insert M3 Precision Shim Washers

| Insert 4xM3 washers | Washers inserted |
| - | - |
| <img src="pictures/yaxis_l_xyidler_c007.PNG" width="350" /> | <img src="pictures/yaxis_l_xyidler_c008.PNG" width="350" /> |

##### Step 5 - Insert second pulley in bolt

| Insert 2nd GT2 pulley | Insert M3x30mm bolt till end |
| - | - |
| <img src="pictures/yaxis_l_xyidler_c009.PNG" width="350" /> | <img src="pictures/yaxis_l_xyidler_c010.PNG" width="350" /> |

##### Step 6 - Tighten M3x30mm bolt

- Screw in and slightly tighten the M3x30mm bolt with an M3 Allen Wrench
- Do not tighten to the point that the pulleys cannot spin freely!

| Tighten Bolt with Allen Wrench | Final XY Idler assembly |
| - | - |
| <img src="pictures/yaxis_l_xyidler_b006.jpg" width="350" /> | <img src="pictures/yaxis_l_xyidler_c011.PNG" width="320" /> |
---

#### 1.2 Subassembly - XY Stepper Left
   
   Parts required:
   1. Printed Stepper Motor Bracket - Left (1)
         1. M3 Nut (1)
         2. M3x20mm bolt (1)
      1. Nema 17 Motor (1)
      2. GT2 20T Teethed 5 mm Bore Drive Pulley (1)
      3. M3x8mm bolt (1)
      4. M3x10mm bolt (2)

##### Before and After Assembly

| Before Assembly | After Assembly |
| ---- | ---- |
| <img src="/pictures/yaxis_l_xystepper_c0b" width="350" /> | <img src="pictures/yaxis_l_xystepper_c0a" width="350" /> |

##### Exploded view of XY Stepper

<img src="pictures/yaxis_l_xystepper_cev.PNG" />

##### Step 1 - Insert M3 nut into printed stepper motor bracket

##### Step 2 - Insert M3x20mm SHCS but do not tighten so as to deform plastic

##### Step 3 - Place bracket on Nema17 motor

##### Step 4 - Insert M3 Bolts and tighten

#### 1.3 Subassembly - Y-axis smooth rod insertion

   Parts required:
   1. 340mm long 10mm dia smooth rod (1)
   2. Pre-assembled XY Idler Bracket Left
   3. Pre-asssembled XY Stepper Bracket Left

#### Step 1 - Insert 10mm dia 340mm long smooth rod into the XY Idler Left and XY Stepper Left

#### Step 2 - Tighten the M3x20mm SHCS on the XY Idler bracket till the 10mm smooth rod is fixed in place

#### Step 3 - Tighten the M3x20mm SHCS on the XY Stepper Bracket till the 10mm smooth rod is fixed in place


### 2.  Y-axis Right Pre-assembly (1) 

Repeat the same process as in Y-axis pre-aassembly Left. The XY Idler Right and XY Stepper Right are mirrored versions of the XY Idler Left and XY Stepper Left. 

### 3.  Build Platform Pre-assembly
   
#### Parts Required

   1. 2020 Profile 335mm long (2)
   2. 2020 Profile 140mm long (2)
   3. Printed Corner Brackets (4)
      1. M5x8mm Bolt (2)
      2. M5 Hammernut (2)
   4. Z-Axis Bearing Holder (4)
      1. M5x10mm Bolt (4)
      2. M5 2020 Hammer Nuts (4)
      3. LM8UU Bearing (2)
   5. Z Nut Bracket (2)
       1. M5x10 Bolts (4)
       2. 2020 M5 Hammer Nuts (4)
       3. Trapezoidal Lead Screw Nuts 8mm (1)
       4. M3x12 Bolts (4)
       5. M3 Nut (4)
   6. Bed Bracket (4)
       1.  M5x10 Bolts (2)
       2.  M5 2020 Hammer Nuts (2)
       3.  M3x40 Bolts with Springs	(1)
       4.  M3 Hand Tightening Nuts (1)


### 4.  Z-axis lower mount (2)

#### Parts required

1. M3x25 Bolts (2)
2. M3 Nut (2)
3. M5x10 Bolts (4)
4. M5 Hammernut (4)

### 5.  Z-axis upper mount (2)

#### Parts required

1. M3x25mm bolt (2)
2. M3 Nut (2)
3. M5x10 Bolts (4)
4. M5 Hammernut (4)

### 6.  Y-Carriage Pre-assembly (2)

#### Parts required

1. Y-Carriage Printed Part (1)
2. M3 Heatset Insert (4)
3. M3 Nut (4)
4. M3x14mm bolt (2)
5. M3x30mm Bolt (2)
6. GT2 20T Teethed 3mm Bore Smooth Idler Pulley (1)
7. X-End Stop Flag (1)

Instructions:
   1. Insert 

### 7.  X-carriage Pre-assembly (1)
   1. Printed X-Carriage (1)
   2. M3 Heatset Insert (10)
   3. M3x14mm Bolt (4)
   4. 3mm dia 12mm long Dowel Pins (4)
   5. LM8UU Misumi Bearing (3)

### 8.  Extruder Mount Pre-Assembly (1)

 1. Printed Extruder Mount (1)
   1. M3 nut (4)
      1. Insert 2 nuts for extruder motor mount
      2. Insert 2 nuts for retainer bracket mount
 2. X-axis Endstop Assembly (1)
    1. Printed X-endstop holder (1)
    2. Mechanical micro-endstop switch (1)
    3. 26G/24G Wire 4cm long (2)
    4. 2pin JST-XT Female Connector (1)
 3. M3x6mm bolt (1)

### 9.  Exhaust Pre-assembly (1)

#### Parts required

1. Exhaust Housing (1)
  1.  M3 Heatset insert (7)
  2.  PTFE Tube Through Connector (1)
  3.  6020 Fan (1)
  4.  M3x12mm bolt (4)
2. Exhaust Grill (1)
3. Exhaust Mount Bracket (2)
4. Carbon Filter (2)
5. Fan Mount (1)

### 10. Dual Z drive (DZD) Pre-assembly (1) -RECHECK

#### Parts required

1. Printed DZD Housing x1
2. Printed DZD Cover x1
3. M3 nuts x7
4. GT2 B3 W6 smooth Pulley x2
5. GT2 B3 W6 teethed Pulley x1
6. Nema 17 Motor x1
7. M3x18mm SHCS x3
8. M3x20mm SHCS x2

### 11. Power Supply Unit (PSU) Pre-Assembly (1)

#### Parts required

 1.  Meanwell 350W PSU (1)
 2.  PSU Back Cover (1)
 3.  PSU Front Cover (2)
 4.  M3 Nut (2)
 5.  Printed Mid Mount Bracket (1)
 6.  Printed Top Mount Bracket (1)
 7.  M4x8mm bolt (3)
 8.  Power Switch (1)
 9.  M3x8mm bolt (2) 

### 12. Electronics Assembly

1.  MKS Sbase v1.3  Controller Board
    1.  M3x10mm bolt (4)
2.  24-12V Step Down Converter
    1.  M3x6mm bolt (2)
3.  LCD Controller
    1.  M3x8mm bolt (2)


### 13. Door Hinges (3)

#### Parts required

1. Printed inner hinge (1)
2. Printed outer hinge (1)
3. M3 Nut (1)
4. M3x30mm SHCS (1)
5. M5 Hammer nut (1)
6. M5x12mm BHCS (1)

### 14. Y-axis EndStop Assembly (1)

#### Parts required

1.  Mechanical micro endstop (1)
2.  Printed Y-Endstop holder (1)
3.  Printed Y-Endstop top cover (1)
4.  Printed Y-Endstop bracket (1)
5.  M3x8mm SHCS (1)

### 15. X-Y Cable chain assembly

#### Parts required

1. Cable Chain 10x20mm 400mm long (1)
2. Cable Chain 10x20mm 350mm long (1)
3. Printed XY cable chain connector (1)
4. Hotend cable - 2pol - 1,5mm2 - 1.6m long
5. Thermister cable - 2pol - 0.14mm2 - 1.6m long
6. Part cooling fan cable - 2pol - 0.25mm2 - 1.6m long
7. Hotend cooling fan - 2pol - 0.25mm2 - 1.6m long
8. X Endstop cable - 2pol - 0.14mm2 - 1.6m long
9. Extruder motor motor cable - 4pol - 0.5mm2 - 1.6m long


### 16. LCD Display with casing assembly

#### Parts required

 1. MKS TFT32 Display
 2. Printed LCD Bottom Cover
 3. Printed LCD Top Cover
 4. M3 SHCS (4)
 5. 8Pin 50cm long flat ribbon cable (1)
 6. Printed MKS Display to Frame connector
 7. M5x12mm BHCS (2)
 8. M5 Hammer nut (2)


---
## Final Assembly
---
### 1. Frame

#### Parts required

1. Left Side Frame (1)
   1. 500mm 3030 profile (2)
   2. 340mm 3030 profile (3)
   3. L bracket (6) with (2) set screws each
2. Right Side Frame (1)
   1. 500mm 3030 profile (2)
   2. 340mm 3030 profile (3)
   3. L bracket (6) with (2) set screws each
3. Left side to right side connection
   1. 3030 profile 340mm (4)
   2. L bracket (8) with (2) set screws each
4. Corner brackets installation
   1. Corner brackets (12) each with:
      1. M6x12mm SHCS (2)
      2. M6 Hammer nut (2)
5. Set Square
6. Allen Wrench Sizes 2.5 and 3
7. 170mm printed spacer
8. 10mm printed spacer

##### Step 0 - Prepare L bracket (20) and Corner bracket (12)

- Insert set screw (2) into each L bracket 
- Pic1 > Inserting set screws into L bracket
- Pic2 > Screwing in set screw with Allen Wrench #3
- Pic3 > L bracket with set screws inserted
- Pic4 > Arrows showing L bracket movement DOF

- Insert M6x12mm SHCS (2) into corner bracket
- Screw on M6 hammer nut (2)

 **Note: ALL vertical profiles (4) are 500mm long and ALL horizontal profiles (10) are 340mm long**

#### Subassembly 1.1 - Left Side Frame

##### Parts required

1. 3030 profile 500mm - vertical (2) 
2. 3030 profile 340mm - horizontal (3)
3. L bracket (6) with (2) set screws each
4. Corner bracket (2)
   1. M6x12mm SHCS (2)
   2. M6 Hammer nut (2)
5. Set Square
6. Allen Wrench 2.5 and 3

##### Step 1 - Connect vertical and horizontal profile

- Insert free end of L bracket into vertical 500mm profile
- Insert fixed end into horizontal 340mm profile
- Check alignment with Set Square
- Tighten set screws in L bracket

##### Step 2 - Connect second Vertical profile

- Repeat process as in Step 2

##### Step 3 - Install middle horizontal profile

- Insert 2x L bracket with fixed end into horizontal profile
- Slide Horizontal profile with 2x L bracket into inside of vertical profiles
- Place 170mm spacer on left side and tighten L bracket set screws
- Place 170mm spacer on right side and tighten L bracket set screws

##### Step 4 - Install bottom horizontal profile

- Insert fixed end of L bracket (2) into horizontal profile
- Slide horizontal profile with free end of L brackets moving into vertical profiles inner slots
- Place 10mm printed spacer on intersection and tighten L bracket set screws
- Check alignment with Set square on left and right side
- Tighten L bracket set screws
- Left Side frame is finsihed

#### Subassembly 1.2 - Right Side Frame

Repeat exact same process as in previous Left Side frame subassembly

#### Subassembly 1.3 - Connect Left and Right Side Frames

##### Parts required

1. Left side frame (1)
2. Right side frame (1)
3. Horizontal profile (8)
4. L bracket with set screws (16)
5. Corner Brackets with M6 bolts and hammer nuts (8)

##### Step 1 - Mount horizontal profiles (4) into left side frame

- Place left side frame flat on table
- Insert L bracket (2) into vertical profiles of top side of frame of left 
- Insert L bracket (2) with free end into vertical profiles of left side frame
- Insert horizontal profile (4) onto inserted L brackets
- Use Set Square to check 90degrees angle between profiles
- Tighten set screws on L brackets

##### Step 2 - Mount right side frame

- Insert fixed end of L bracket (4) onto previously mounted horizontal profiles
- Mount Right hand side frame onto L brackets and tighten the set screws with allen wrench #3

##### Step 3 - Install corner brackets (8)

- Install corner brackets (8) with preassembled M6x12mm SHCS (2) and M6 hammer nuts (2)
- Check right angle alignment with Set Square
- Tighten with Allen wrench #3
- Frame is finished

### 2. Z-axis lower mounts installation (2)

#### Parts required

1. Preassembled Z axis lower mount (2)
2. M5x12mm BHCS (8)
3. M5 Hammernut (8)
4. 62 mm printed spacer (1)
5. Allen wrench #3

#### Assembly process

- Use 62mm spacer to align lower Z mount to front side of frame
- Tighten M5x12mm BHCS (4) pre-installed on lower Z mount
- Install M5x12mm BHCS (2) with M5 hammer nut on underside of lower Z mount
- Install the second lower Z mount on right side following above process

### 3. 8mm rods insertion in Z axis lower mounts

- Insert 8mm smooth rod (4) into hole in Z-axis lower mounts
- Tighten the M3x25mm SHCS screw to fix the smooth rods in place

### 4. Build Platform Mounting (1)

- Insert the pre-assembled build platform into the 8mm smooth rods

### 5. Z-axis upper mounts installation (2)

#### Parts required

 1. Preassembled Z upper mount (2)
 2. M5x12mm BHCS (4)
 3. M5 Hammernut (4)
 4. 62 mm printed spacer (1)
 5. Allen wrench #3

#### Assembly process

- Mount Z axis upper mount assembly with hammer nut 62mm printed spacer placed to front side of frame
- Insert M5x10 BHCS (2) with Hammer nut (2) into Z axis upper mount and tighten with #3 allen wrench
- Repeat process for second Z axis upper mount on right side of frame


### 6. Y-axis Left Installation (2)

#### Parts required

1. Preassembled  left (1)
2. M5x12mm BHCS (1)
3. M5 hammernut (1)
4. 100 mm printed spacer (1)

#### Step 1 - 

5. Fixing XY Stepper Motor Bracket to Frame
   1. M5x12mm SHCS (1)
   2. M5 Hammer Nut (1)


- Fixing XY Idler Assembly - Left (1)
  - Tighten M5x10mm bolt (2)

1. Y-axis Right (1)
   1. XY Stepper Motor Assembly (1)
      1. Printed Stepper Motor Bracket - Right (1)
         1. M3 Nut (1)
         2. M3x20mm bolt (1)
      2. Nema 17 Motor (1)
         1. GT2 20T Teethed 5 mm Bore Drive Pulley (1)
      3. M3x8mm bolt (1)
      4. M3x10mm bolt (2)
      5. M5x10mm bolt (3)
      6. M5 Hammer Nut (3)
   2. 10mm dia 340mm long Smooth Rod (1)
   3. LMW10U Bearing (1)
   4. XY Idler Assembly - Right (1)
      1. Printed XY Idler - Right (1)
         1. M3 Nut (2)
         2. M3x20mm bolt (1)
      2. M3x30mm bolt (1)
      3. 3mm Bore GT2 Pulley (2)
      4. M3 shim washer (4)
      5. M5x10mm bolt (2)
      6. M5 Hammer Nut (2)

2.  X-axis Assembly (1)
   5. Y Carriage Pre-assembled (Left)
   6. Y End Stop Flag (1)
      1. M3x6mm Bolt (1)
   7. Y Carriage Clamps (4)
      1. 8.3.1 M3x16 Bolts (4)
   8. 8 mm Rods (2)
   9. X-Carriage Assembly
      1. Printed X-Carriage (1)
      2. Belt Tensioners (4)
     
     
      3. Belt Clamp (1)
      4. Belt Clamp + X Cable Chain Connector (1)
      5. 3mm dia 12mm long Dowel Pins (4)

3.  XY Belts Installation
    1.  1.4m long GT2 6mm wide belt (2)
    2.  (P) Belt Tensioner (4)
    3.  (P) Belt Clamp (1)
    4.  (P) Belt Clamp + XCable Chain Bracket (1)

4.  Y Axis End Stop Installation
    1. Endstop Bracket (1)
    2. Endstop Housing (1)
    3. Endstop Cover (1)
    4. Mechanical Endstop (1)
    5.  M3x10 Bolts (1)
    6.  M5 Hammernut (1)
    7.  M3x10 Bolts (1)

5.  X-Y Cable Chain Installation
    1. X Cable Chain (1)
    2. Y Cable Chain (1)
    3. X-Y Cable Chain Connector Top and Bottom (1)
    4. Y Cable Chain to Frame Connector 	
       1. M3x8mm bolt (2)
       2. M3 Nut (2)
    5. X Cable Chain to Extruder Connector	
       1. M3 Nut (2)
       2. M3x6 Bolts (2)
       3. M3x14 Bolts (2)
       4. M3x8 Bolts (1)

6.  Electronics plate
    1.  Dibond Plate 218x329mm (1)
    2.  MKS Controller board
        1.  MKS Controller Board Housing
        2.  MKS Controller Board Top Cover
        3.  M3x10mm bolt (4)
    3. 24 to 12V Converter (1)
       1. LM2596 Buck Converter (1)
       2. M3x6mm bolt (2)
    4. LED Controller (1)
       1. m3x6mm bolt (2)
    5. Electronics Plate Mounting Bracket (4)
       1. M5x10mm Bolt (1)
       2. M5 Hammernut (1)

7.  PSU Mounting
    1.  Preassembled PSU Unit (1)
    2.  M5x10mm bolt (3)
    3.  M5 Hammernut (3)

8.  Heated bed installation

#### Parts required

1. Mk3 214x214mm Aluminium Heatbed (1)
2. M3x40mm bolt (4)
3. M3 Knurled Nut (4)
4. 3mm Borosilicate Glass Plate (1)
5. Bulldog Clip (4)



6.  Connect Wiring
    1.  Power cables from PSU to Controller
    2.  Heatbed Power cables
    3.  Hotend Power
    4.  Part Cooling Fan
    5.  Hotend Fan
    6.  Heatbed Thermister
    7.  Hotend Thermister
    8.  Stepper Motor (4)
    9.  X and Y Endstop
    10. Inductive Probe
    11. LED Controller
    12. DC-DC Converter

7.  Exhaust system (1)
    1.  Preassembled Exhaust System (1)
    2.  M5x10mm Bolt (2)
    3.  M5 hammernut (2)

8.  Printed Spool Holder (1)
    1.  M5x10mm bolt (1)
    2.  M5 Hammernut (1)

9.  Printed Flament Guide (1)
    1.  M5x10mm bolt (1)
    2.  M5 Hammernut (1)

10. Single Motor Z Drive Assembly 
    1. Printed Housing (1)
    2. Printed Cover (1)
    3. M3 Nut (4)
    4. Toothless GT2 20T 3 mm Bore Idle Pulley (2)
    5. Toothed GT2 20T 3 mm Bore Idle Pulley (1)
    6. Nema 17 Motor (1)
    7. Toothed GT2 20T Drive Pulley 5 mm Bore (1)
    8. Printed Screw Bolt (1)
    9. M3 Nut (1)
    10. M3x18 (1)
    11. M3x8 Bolt (1)
    12. M3x18 Housing (4)
    13. M3x20 (3)

11. Lead Screw with Z Mount Assembly	
    1. Z Bottom Bearing Holder	Left and Right (2)
        1. 8 mm Lead Screw (1)
        2. Z Bottom Bearing Holder (1)
        3. Z Bottom Bearing Nuts (1)
        4. 608ZZ Bearings (2)
        5. GT2 40 Teethed 8mm Bore Pulley (1)
        6. M5x10 Bolts (2)
        7. M5 Hammer Nuts (2)
        8. 1100 mm Long, 6mm Wide Closed GT2 Belt (1)

12. Z axis bottom mount A (1)
    1. M3x25 Bolts (1)
    2. M3 Nut (1)
    3. M5x10 Bolts (2)
    4. M5 Hammernut (2)

13. Z axis bottom mount B (1)
    1. M3x25mm Bolt (1)
    2. M3 Nut (1)
    3. M5x10mm Bolt (2)
    4. M5 Hammernut (2) 

14. Enclosure Panels
    1.  Front Door (1)
        1.  Hinge Assembly (3)
           
    2.  Left Side Panel (1)
    3.  Right Side Panel (1)
    4.  Back Panel dibond (1)
    5.  Top Panel (1)  



Reference code for picture to show in mkdocs with html picture sizing:


<img src="https://gitlab.fabcity.hamburg/hardware/open-lab-starter-kit/-/raw/master/docs/machines/3DPrinter/pictures/yaxis_l_xyidler_c0b.PNG" width="350" /> 